Owlmixin API Reference
======================

Github and README: https://github.com/tadashi-aikawa/owlmixin

.. toctree::
    :maxdepth: 4

    api/owlmixin
    api/owlcollections
    api/owloption
    api/owlenum
    api/errors


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
